==> am_mod_lbr_0_3.tar.gz: am_mod_lbr_0_3/components/lbr/language/1/barnraiser_01/revision_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');


//HEADER
$lang['hdr_page'] = 								"wiki page";
$lang['hdr_revise'] = 								"revise the page contents";


// ERRORS
$lang['error']['interlink_name_error'] = 		"You can only use uppercase, lowercase characters or numbers for interlink names (not spaces for instance)";



// SUBMIT BUTTONS
$lang['sub_preview'] =                        		"preview";
$lang['sub_insert'] =                            	"submit new revision";


//BODY TEXT
$lang['txt_revision_body'] = 						"revision body";
$lang['txt_revision_note'] = 						"notes";
$lang['txt_wiki_name'] = 							"wiki name";

?>

==> am_mod_lbr_0_7.tar.gz: am_mod_lbr_0_7/components/lbr/language/1/barnraiser_01/revision_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');


//HEADER
$lang['hdr_revise'] = 								"revise the page contents";


// ERRORS
$lang['error']['interlink_name_error'] = 			"You can only use uppercase, lowercase characters or numbers for interlink names (not spaces for instance)";



// SUBMIT BUTTONS
$lang['sub_preview'] =                        		"validate";
$lang['sub_insert'] =                            	"submit new revision";


//BODY TEXT
$lang['txt_revision_body'] = 						"revision body";
$lang['txt_revision_note'] = 						"notes";
$lang['txt_wiki_name'] = 							"wiki name";

$lang['txt_wiki_page'] = 							"wiki page revision";
$lang['txt_title_intro'] = 							"describe your wiki page revision";
$lang['txt_title_create'] = 						"create your wiki page revision";
$lang['txt_title_save'] = 							"check and save your wiki page revision";

?>
